@@ -17,12 +17,13 @@
 
 # GOOGLE_MAPS_API_KEY = 'ABQIAAAApZ2euq0Rw9q9gnvrFpM9exTnaMynjZlWua31ZRN9Bu7KwLftLRQ43gnDTGdinhoU7RuKLZRQxMKcVg'
 GOOGLE_MAPS_API_KEY = ''
-VERSION_STRING = 'barriosquare 0.2.4'
-SHORT_VERSION_STRING = '0.2.4'
+VERSION_STRING = 'barriosquare 0.3.1'
+SHORT_VERSION_STRING = '0.3.1'
 # key and secret granted by the service provider for this consumer application - same as the MockOAuthDataStore
 CONSUMER_KEY = '73da08e67b46cb1dc10fd43ea813071104af9fe79'
 CONSUMER_SECRET = 'c9fadf4a225e74d907053aecd12f23d5'
-
+TWITTER_CONSUMER_KEY = 'dcfjDyRq44d5AcVnFG5TgA'
+TWITTER_CONSUMER_SECRET = 'iOdH21SjnN5CQWDXbsiFgiIjqqMrvva03OnpvmmS0'
 SERVER = 'foursquare.com'
 PORT = 80
 API_PREFIX_URL = 'http://api.foursquare.com/v1/'
