@@ -2,7 +2,7 @@
 #
 # barriosqdata.py - barrioSquare data access layer
 # 
-# barrioSquare v0.2.5
+# barrioSquare v0.3.1
 # Copyright(c) 2010 Chili Technologies LLC
 # http://www.chilitechno.com/fster
 #
@@ -32,7 +32,7 @@
 # ============================================================================
 # Name        : barriodata.py
 # Author      : Chris J. Burris - chris@chilitechno.com
-# Version     : 0.2.5
+# Version     : 0.3.1
 # Description : barrioSquare
 # ============================================================================
 
@@ -354,6 +354,43 @@ class DataManager(QtCore.QObject):
 		if self.selectQueryThread != None:
 			self.selectQueryThread.doSelectQuery(queryParams)
 			
+	def updateUserStats(self,userID,checkinsCount,nightsCount):
+		queryParams = { }
+								
+		queryParams['Action'] = 'Update'
+		queryParams['UPDATE'] = "UPDATE UserDetails SET  stats_TotalNightsOut=%d, stats_TotalCheckins=%d WHERE userID='%s'" % (nightsCount,checkinsCount,userID)
+		if self.insertUpdateDeleteThread != None:
+			self.insertUpdateDeleteThread.insertUpdateDeleteQuery(queryParams)		
+						
+	def setVenueMayorshipsForUser(self,venueIDList,userID):
+		queryParams = { }
+
+		queryParams['Action'] = 'Delete'
+		queryParams['DELETE'] = "DELETE FROM VenueMayors WHERE VenueID in (%s)" % venueIDList
+		
+		# queryParams['UPDATE'] = "UPDATE UserCheckinHistory SET userID='%s', calculatedDistance=%s, distanceCalcDate='%s', CustomVenue='%s', displayString='%s' WHERE id='%s'" % (self.safeStr(userID),calcDistance,strNow,self.safeStr(customVenueName),self.safeStr(displayString),self.safeStr(checkinID))
+		if self.insertUpdateDeleteThread != None:
+			self.insertUpdateDeleteThread.insertUpdateDeleteQuery(queryParams)
+			
+		venueIDs = venueIDList.split(",")
+		sqlStr = ""
+		for venueID in venueIDs:
+			sqlStr = "INSERT INTO VenueMayors(userID, venueID) VALUES('%s', %s);" % (self.safeStr(userID),venueID)
+			
+			print sqlStr
+			queryParams2 = { }
+				
+			queryParams2['Action'] = 'Insert'
+			queryParams2['TABLE'] = 'VenueMayors'
+			queryParams2['PrimaryKeyColumn'] = 'venueID'
+			queryParams2['PrimaryKey'] = '-1'
+			queryParams2['INSERT'] = sqlStr
+			
+			if self.insertUpdateDeleteThread != None:
+				self.insertUpdateDeleteThread.insertUpdateDeleteQuery(queryParams2)		
+				
+			del queryParams2			
+			
 	def addEditCategory(self,catID,catNodeName,fullPathName,catIconUrl,iconFilePath):
 		queryParams = { }
 
