@@ -29,12 +29,12 @@ or find one that works with your web framework.
 
 import httplib
 import time
-import oauth
+import oauthlib
 
-USER_AGENT = 'barriosquare:0.2.4 (Maemo5; Linux arm7vl) (http://chilitechno.com/fster/)'
+USER_AGENT = 'barriosquare:0.3.1 (Maemo5; Linux arm7vl) (http://chilitechno.com/fster/)'
 
 # example client using httplib with headers
-class SimpleOAuthClient(oauth.OAuthClient):
+class SimpleOAuthClient(oauthlib.OAuthClient):
 
     def __init__(self, server, port=httplib.HTTP_PORT, request_token_url='', access_token_url='', authorization_url=''):
         self.server = server
@@ -51,14 +51,14 @@ class SimpleOAuthClient(oauth.OAuthClient):
 	print oauth_request.to_header()
         self.connection.request(oauth_request.http_method, self.request_token_url, headers=oauth_request.to_header()) 
         response = self.connection.getresponse()
-        return oauth.OAuthToken.from_string(response.read())
+        return oauthlib.OAuthToken.from_string(response.read())
 
     def fetch_access_token(self, oauth_request):
         # via headers
         # -> OAuthToken
         self.connection.request(oauth_request.http_method, self.access_token_url, headers=oauth_request.to_header()) 
         response = self.connection.getresponse()
-        return oauth.OAuthToken.from_string(response.read())
+        return oauthlib.OAuthToken.from_string(response.read())
 
     def authorize_token(self, oauth_request):
         # via url
@@ -88,15 +88,15 @@ def run_example():
     # setup
     print '** OAuth Python Library Example **'
     client = SimpleOAuthClient(SERVER, PORT, REQUEST_TOKEN_URL, ACCESS_TOKEN_URL, AUTHORIZATION_URL)
-    consumer = oauth.OAuthConsumer(CONSUMER_KEY, CONSUMER_SECRET)
-    signature_method_plaintext = oauth.OAuthSignatureMethod_PLAINTEXT()
-    signature_method_hmac_sha1 = oauth.OAuthSignatureMethod_HMAC_SHA1()
+    consumer = oauthlib.OAuthConsumer(CONSUMER_KEY, CONSUMER_SECRET)
+    signature_method_plaintext = oauthlib.OAuthSignatureMethod_PLAINTEXT()
+    signature_method_hmac_sha1 = oauthlib.OAuthSignatureMethod_HMAC_SHA1()
     pause()
 
     # get request token
     print '* Obtain a request token ...'
     pause()
-    oauth_request = oauth.OAuthRequest.from_consumer_and_token(consumer, callback=CALLBACK_URL, http_url=client.request_token_url)
+    oauth_request = oauthlib.OAuthRequest.from_consumer_and_token(consumer, callback=CALLBACK_URL, http_url=client.request_token_url)
     oauth_request.sign_request(signature_method_plaintext, consumer, None)
     print 'REQUEST (via headers)'
     print 'parameters: %s' % str(oauth_request.parameters)
@@ -110,7 +110,7 @@ def run_example():
 
     print '* Authorize the request token ...'
     pause()
-    oauth_request = oauth.OAuthRequest.from_token_and_callback(token=token, http_url=client.authorization_url)
+    oauth_request = oauthlib.OAuthRequest.from_token_and_callback(token=token, http_url=client.authorization_url)
     print 'REQUEST (via url query string)'
     print 'parameters: %s' % str(oauth_request.parameters)
     pause()
@@ -129,7 +129,7 @@ def run_example():
     # get access token
     print '* Obtain an access token ...'
     pause()
-    oauth_request = oauth.OAuthRequest.from_consumer_and_token(consumer, token=token, verifier=verifier, http_url=client.access_token_url)
+    oauth_request = oauthlib.OAuthRequest.from_consumer_and_token(consumer, token=token, verifier=verifier, http_url=client.access_token_url)
     oauth_request.sign_request(signature_method_plaintext, consumer, token)
     print 'REQUEST (via headers)'
     print 'parameters: %s' % str(oauth_request.parameters)
